.. _Citing_MetPy:

Citing MetPy
============

If MetPy played an important role in your research, then please add us to
your reference list using one of the options below.
MetPy also maintains a ``CITATION.cff`` [#]_ file with human- and machine-readable
metadata for generating up-to-date citations.

DOI: `10.5065/D6WW7G29 <https://doi.org/10.5065/D6WW7G29>`_

************
BibTeX entry
************

Example BibTeX entry:

.. parsed-literal::

  @software{metpy,
    author = {May, Ryan M. and Arms, Sean C. and Marsh, Patrick and Bruning, Eric and Leeman,
              John R. and Goebbert, Kevin and Thielen, Jonathan E. and Bruick, Zachary S and Camron, M. Drew.},
    organization = {Unidata},
    title = {MetPy: A {Python} Package for Meteorological Data},
    year = {|cite_year|},
    version = {|cite_version|},
    doi = {10.5065/D6WW7G29},
    url = {https://github.com/Unidata/MetPy},
  }


*****************
AMS Journal Style
*****************

AMS suggested BibTeX entry:

.. parsed-literal::

  @misc{metpy,
    author = {May, Ryan M. and Arms, Sean C. and Marsh, Patrick and Bruning, Eric and Leeman,
              John R. and Goebbert, Kevin and Thielen, Jonathan E. and Bruick, Zachary S. and Camron, M. Drew.},
    publisher = {Unidata},
    title = {MetPy: A {Python} Package for Meteorological Data},
    year = {|cite_year|},
    doi = {10.5065/D6WW7G29},
    note = {\url{https://github.com/Unidata/MetPy}},
  }


Example Citation:

.. parsed-literal::

  May, R. M., Arms, S. C., Marsh, P., Bruning, E., Leeman, J. R., Goebbert, K., Thielen, J. E.,
      Bruick, Z., and Camron, M. D., |cite_year|: MetPy: A Python Package for Meteorological Data.
      Unidata, https://github.com/Unidata/MetPy, doi:10.5065/D6WW7G29.

.. [#] https://citation-file-format.github.io
